@@ -1,9 +1,9 @@
 # system packages
+import re
 import sys
 import time
 import pika
 import logging
-from scrapy.utils.reqser import request_to_dict
 # module packages
 from . import connection
 from . import picklecompat
@@ -73,7 +73,7 @@ class RabbitMQQueue(IQueue):
 
     def _encode_request(self, request):
         """Encode a request object"""
-        obj = request_to_dict(request, self.spider)
+        obj = request.to_dict(spider=self.spider)
         # return self.serializer.dumps(obj) #指定格式 使用 json @sunny5156
         return json.dumps(obj)
 
