@@ -152,7 +152,7 @@ class RabbitMQScheduler(Scheduler):
         except Exception as e:
             msg = 'Queue {} is error , please reconnect ...'
             logger.info(msg.format(e))
-            #self.open(self.spider)
+            self.open(self.spider)
             return None
 
     def has_pending_requests(self):
